function [] = ...
    plot_the_cladogram( ...
        CladeNames, ...
        CladeExtantXPositions, ...
        CladeExtantYPositions, ...
        CladeExtinctXPositions, ...
        CladeExtinctYPositions, ...
        CladeInfoFileName)

    % ---------------------------------------------------------------------

    figure;
    hold on;
    axis off;
    set(gcf, 'Color', 'white');

    % ---------------------------------------------------------------------

    for i = 1:length(CladeNames)

        % Label each clade in turn
        if i == 1

            % The common parent goes to the top left
            text(CladeExtantXPositions(i, 1), CladeExtantYPositions(i, 2), ...
                 CladeNames(i), ...
                 'HorizontalAlignment', 'Left', ...
                 'VerticalAlignment',   'bottom', ...
                 'FontName',            'Candara', ...
                 'FontSize',            7);

            TheLineWidth = 2;
             
        else

            % All the others on the right
            text(CladeExtinctXPositions(i, 2), CladeExtinctYPositions(i, 2), ...
                 CladeNames(i), ...
                 'HorizontalAlignment', 'Right', ...
                 'VerticalAlignment',   'bottom', ...
                 'FontName',            'Candara', ...
                 'FontSize',            7);

            TheLineWidth = 1;
             
        end

        plot(CladeExtantXPositions(i, :),  CladeExtantYPositions(i, :),   '-k', 'LineWidth', TheLineWidth);

        plot(CladeExtinctXPositions(i, :), CladeExtinctYPositions(i, :), '--k', 'LineWidth', TheLineWidth);

    end

    % ---------------------------------------------------------------------
    
    set(gca, 'position', [0.01 0.01 0.98 0.96]);
    axis tight;

    % ---------------------------------------------------------------------
    % Save the cladogram
    saveas(gcf, CladeInfoFileName, 'fig');
    print('-dpng', '-r120', [CladeInfoFileName '.png']);

    % ---------------------------------------------------------------------

end